'use strict';

let {
    S3
} = require("@aws-sdk/client-s3");
let s3 = new S3();
const fs = require('fs');
//var _downloadKey = 'agentextensions/latest/web-site-manifest.json';
var _downloadKey = '';
const _downloadLocation = './web-site-manifest.json';

/**
 * Helper function to interact with s3 hosted website for cfn custom resource.
 *
 * @class websiteHelper
 */
let websiteHelper = (function() {

    /**
     * @class websiteHelper
     * @constructor
     */
    let websiteHelper = function() {};

    /**
     * Provisions the web site UI at deployment.
     * @param {string} sourceS3Bucket - Bucket containing the web site files to be copied.
     * @param {string} sourceS3prefix - S3 prefix to prepend to the web site manifest file names to be copied.
     * @param {string} destS3Bucket - S3 destination bucket to copy website content into
     * @param {string} destS3KeyPrefix - S3 file prefix (website folder) for the website content
     * @param {string} userPoolId - Cognito User Pool Id for web site configuration
     * @param {string} userPoolClientId - Cognito User Pool Client Id for web site configuration
     * @param {string} identityPoolId - Cognito Identity Pool ID
     * @param {string} region - Region of destination S3 bucket
     * @param {copyWebSiteAssets~requestCallback} cb - The callback that handles the response.
     */
    websiteHelper.prototype.copyWebSiteAssets = function(resourceProperties, cb) {
		var sourceS3Bucket = resourceProperties.sourceS3Bucket;
		var sourceS3prefix = resourceProperties.sourceS3key ;
		var destS3Bucket = resourceProperties.destS3Bucket;
		var destS3KeyPrefix = resourceProperties.destS3KeyPrefix;
		var region = resourceProperties.Region;
		var instanceID = resourceProperties.instanceID;
    var instanceName = resourceProperties.instanceName;
    var gatewayAPI = resourceProperties.gatewayAPI;
    var identityPoolId = resourceProperties.identityPoolId;
    var locationMapName = resourceProperties.locationMapName;

        console.log("Copying UI web site");
        console.log(['source bucket:', sourceS3Bucket].join(' '));
        console.log(['source prefix:', sourceS3prefix].join(' '));
        console.log(['destination bucket:', destS3Bucket].join(' '));
        console.log(['destination s3 key prefix:', destS3KeyPrefix].join(' '));
        console.log(['region:', region].join(' '));
        console.log(['instanceID:', instanceID].join(' '));
        console.log(['instanceName:', instanceName].join(' '));
        console.log(['gatewayAPI:', gatewayAPI].join(' '));
        console.log(['identityPoolId:', identityPoolId].join(' '));
        console.log(['locationMapName:', locationMapName].join(' '))


           fs.readFile(_downloadLocation, 'utf8', function(err, data) {
                if (err) {
                    console.log(err);
                    return cb(err, null);
                }

                console.log(data);
                let _manifest = validateJSON(data);

                if (!_manifest) {
                    return cb('Unable to validate downloaded manifest file JSON', null);
                } else {
                    uploadToS3(_manifest.files, 0, destS3Bucket, destS3KeyPrefix, sourceS3Bucket, sourceS3prefix,
                        function(err, result) {
                            if (err) {
                                return cb(err, null);
                            }
                            console.log(result);
                            createAWSCredentials(destS3Bucket, destS3KeyPrefix, gatewayAPI, region,  instanceID, instanceName, identityPoolId, locationMapName,
                                function(err, createResult) {
                                    if (err) {
                                        return cb(err, null);
                                    }
                                    return cb(null, createResult);
                                });
                        });
                }

        });

    };


    /**
     * Helper function to validate the JSON structure of contents of an import manifest file.
     * @param {string} body -  JSON object stringify-ed.
     * @returns {JSON} - The JSON parsed string or null if string parsing failed
     */
    let validateJSON = function(body) {
        try {
            let data = JSON.parse(body);
            console.log(data);
            return data;
        } catch (e) {
            // failed to parse
            console.log('Manifest file contains invalid JSON.');
            return null;
        }
    };

    async function uploadToS3(filelist, index, destS3Bucket, destS3KeyPrefix, sourceS3Bucket, sourceS3prefix,cb) {
      if (filelist.length > index) {
          const response = fs.readFileSync(filelist[index], 'utf8');
          var fileDetails = filelist[index]
          fileDetails = fileDetails.substring(2, fileDetails.length);

          let params2 = {
              Bucket: destS3Bucket,
              Key: destS3KeyPrefix + '/' + fileDetails,
              Body: response
          };
            if (filelist[index].endsWith('.htm') || filelist[index].endsWith('.html')) {
                params2.ContentType = "text/html";
            } else if (filelist[index].endsWith('.css')) {
                params2.ContentType = "text/css";
            } else if (filelist[index].endsWith('.js')) {
                params2.ContentType = "application/javascript";
            } else if (filelist[index].endsWith('.png')) {
                params2.ContentType = "image/png";
            } else if (filelist[index].endsWith('.jpg') || filelist[index].endsWith('.jpeg')) {
                params2.ContentType = "image/jpeg";
              } else if (filelist[index].endsWith('.pdf')) {
                  params2.ContentType = "application/pdf";
            } else if (filelist[index].endsWith('.gif')) {
                params2.ContentType = "image/gif";
            } else if (filelist[index].endsWith('.svg')) {
                params2.ContentType = "image/svg+xml";
            };

          s3.putObject(params2, function(err, data) {
                if (err) {
                    console.log(err);
                    return cb(['error copying ', [sourceS3prefix, filelist[index]].join('/'), '\n', err]
                        .join(
                            ''),
                        null);
                }

                console.log([
                    [sourceS3prefix, filelist[index]].join('/'), 'uploaded successfully'
                ].join(' '));
                let _next = index + 1;
                uploadToS3(filelist, _next, destS3Bucket, destS3KeyPrefix, sourceS3Bucket, sourceS3prefix, function(err, resp) {
                    if (err) {
                        return cb(err, null);
                    }

                    cb(null, resp);
                });
            });
        } else {
            cb(null, [index, 'files copied'].join(' '));
        }
    }

    let createAWSCredentials = function(destS3Bucket, destS3KeyPrefix, gatewayAPI, region, instanceId, instanceName, identityPoolId, locationMapName, cb) {
        let str = "function initAWS(){ \n";
        str+= " 	AWS.config.region = '" + region  +"'; \n";
        str+= "   } \n\n";
        str+= "   \n $(document).ready(initAWS); \n ";
        str+= "   \n\n";
        str+= "   function getRegion(){ \n";
        str+= "      return '" + region + "';\n";
        str+= "   } \n\n";
        str+= "   function getGatewayAPI(){ \n";
        str+= "      return '" + gatewayAPI + "';\n";
        str+= "   } \n\n";
        str+= "   function getInstanceId(){ \n";
        str+= "      return '" + instanceId + "';\n";
        str+= "   } \n\n";
        str+= "   function getInstanceName(){ \n";
        str+= "      return '" + instanceName + "';\n";
        str+= "   } \n\n";
        str+= "   function getIdentityPoolId(){ \n";
        str+= "      return '" + identityPoolId + "';\n";
        str+= "   } \n\n";
        str+= "   function getLocationMapName(){ \n";
        str+= "      return '" + locationMapName + "';\n";
        str+= "   } \n\n";
        //console.log(str);
        let params = {
            Bucket: destS3Bucket,
            Key: destS3KeyPrefix + '/js/aws-credentials.js',
            ContentType : "application/javascript",
            Body: str
        };

        s3.putObject(params, function(err, data) {
            if (err) {
                console.log(err);
                return cb('error creating ' +destS3Bucket+ ' ' + destS3KeyPrefix +  '/js/aws-credentials.js file for website UI', null);
            }
            console.log('Completed uploading aws-credentials.js')
            console.log(data);
            return cb(null, data);
        });
    };

    return websiteHelper;

})();

module.exports = websiteHelper;
